/*
 * This code is auto-generated from Wikidata data. Licensed under CC0.
 */

#ifndef KITINERARY_KNOWLEDGEDB_TIMEZONEDB_DATA_P_H
#define KITINERARY_KNOWLEDGEDB_TIMEZONEDB_DATA_P_H

#include <cstdint>

namespace KItinerary {
namespace KnowledgeDb {

/** Enum representing all timezones, values match the offsets into the timezone name string table. */
enum class Tz : uint16_t {
    Africa_Abidjan = 0,
    Africa_Accra = 15,
    Africa_Addis_Ababa = 28,
    Africa_Algiers = 47,
    Africa_Asmara = 62,
    Africa_Bamako = 76,
    Africa_Bangui = 90,
    Africa_Banjul = 104,
    Africa_Bissau = 118,
    Africa_Blantyre = 132,
    Africa_Brazzaville = 148,
    Africa_Bujumbura = 167,
    Africa_Cairo = 184,
    Africa_Casablanca = 197,
    Africa_Ceuta = 215,
    Africa_Conakry = 228,
    Africa_Dakar = 243,
    Africa_Dar_es_Salaam = 256,
    Africa_Djibouti = 277,
    Africa_Douala = 293,
    Africa_El_Aaiun = 307,
    Africa_Freetown = 323,
    Africa_Gaborone = 339,
    Africa_Harare = 355,
    Africa_Johannesburg = 369,
    Africa_Juba = 389,
    Africa_Kampala = 401,
    Africa_Khartoum = 416,
    Africa_Kigali = 432,
    Africa_Kinshasa = 446,
    Africa_Lagos = 462,
    Africa_Libreville = 475,
    Africa_Lome = 493,
    Africa_Luanda = 505,
    Africa_Lubumbashi = 519,
    Africa_Lusaka = 537,
    Africa_Malabo = 551,
    Africa_Maputo = 565,
    Africa_Maseru = 579,
    Africa_Mbabane = 593,
    Africa_Mogadishu = 608,
    Africa_Monrovia = 625,
    Africa_Nairobi = 641,
    Africa_Ndjamena = 656,
    Africa_Niamey = 672,
    Africa_Nouakchott = 686,
    Africa_Ouagadougou = 704,
    Africa_Porto_Novo = 723,
    Africa_Sao_Tome = 741,
    Africa_Tripoli = 757,
    Africa_Tunis = 772,
    Africa_Windhoek = 785,
    America_Adak = 801,
    America_Anchorage = 814,
    America_Anguilla = 832,
    America_Antigua = 849,
    America_Araguaina = 865,
    America_Argentina_Buenos_Aires = 883,
    America_Argentina_Catamarca = 914,
    America_Argentina_Cordoba = 942,
    America_Argentina_Jujuy = 968,
    America_Argentina_La_Rioja = 992,
    America_Argentina_Mendoza = 1019,
    America_Argentina_Rio_Gallegos = 1045,
    America_Argentina_Salta = 1076,
    America_Argentina_San_Juan = 1100,
    America_Argentina_San_Luis = 1127,
    America_Argentina_Tucuman = 1154,
    America_Argentina_Ushuaia = 1180,
    America_Aruba = 1206,
    America_Asuncion = 1220,
    America_Atikokan = 1237,
    America_Bahia = 1254,
    America_Bahia_Banderas = 1268,
    America_Barbados = 1291,
    America_Belem = 1308,
    America_Belize = 1322,
    America_Blanc_Sablon = 1337,
    America_Boa_Vista = 1358,
    America_Bogota = 1376,
    America_Boise = 1391,
    America_Cambridge_Bay = 1405,
    America_Campo_Grande = 1427,
    America_Cancun = 1448,
    America_Caracas = 1463,
    America_Cayenne = 1479,
    America_Cayman = 1495,
    America_Chicago = 1510,
    America_Chihuahua = 1526,
    America_Costa_Rica = 1544,
    America_Creston = 1563,
    America_Cuiaba = 1579,
    America_Curacao = 1594,
    America_Danmarkshavn = 1610,
    America_Dawson = 1631,
    America_Dawson_Creek = 1646,
    America_Denver = 1667,
    America_Detroit = 1682,
    America_Dominica = 1698,
    America_Edmonton = 1715,
    America_Eirunepe = 1732,
    America_El_Salvador = 1749,
    America_Fort_Nelson = 1769,
    America_Fortaleza = 1789,
    America_Glace_Bay = 1807,
    America_Godthab = 1825,
    America_Goose_Bay = 1841,
    America_Grand_Turk = 1859,
    America_Grenada = 1878,
    America_Guadeloupe = 1894,
    America_Guatemala = 1913,
    America_Guayaquil = 1931,
    America_Guyana = 1949,
    America_Halifax = 1964,
    America_Havana = 1980,
    America_Hermosillo = 1995,
    America_Indiana_Indianapolis = 2014,
    America_Indiana_Knox = 2043,
    America_Indiana_Marengo = 2064,
    America_Indiana_Petersburg = 2088,
    America_Indiana_Tell_City = 2115,
    America_Indiana_Vevay = 2141,
    America_Indiana_Vincennes = 2163,
    America_Indiana_Winamac = 2189,
    America_Inuvik = 2213,
    America_Iqaluit = 2228,
    America_Jamaica = 2244,
    America_Juneau = 2260,
    America_Kentucky_Louisville = 2275,
    America_Kentucky_Monticello = 2303,
    America_Kralendijk = 2331,
    America_La_Paz = 2350,
    America_Lima = 2365,
    America_Los_Angeles = 2378,
    America_Lower_Princes = 2398,
    America_Maceio = 2420,
    America_Managua = 2435,
    America_Manaus = 2451,
    America_Marigot = 2466,
    America_Martinique = 2482,
    America_Matamoros = 2501,
    America_Mazatlan = 2519,
    America_Menominee = 2536,
    America_Merida = 2554,
    America_Metlakatla = 2569,
    America_Mexico_City = 2588,
    America_Miquelon = 2608,
    America_Moncton = 2625,
    America_Monterrey = 2641,
    America_Montevideo = 2659,
    America_Montserrat = 2678,
    America_Nassau = 2697,
    America_New_York = 2712,
    America_Nipigon = 2729,
    America_Nome = 2745,
    America_Noronha = 2758,
    America_North_Dakota_Beulah = 2774,
    America_North_Dakota_Center = 2802,
    America_North_Dakota_New_Salem = 2830,
    America_Ojinaga = 2861,
    America_Panama = 2877,
    America_Pangnirtung = 2892,
    America_Paramaribo = 2912,
    America_Phoenix = 2931,
    America_Port_au_Prince = 2947,
    America_Port_of_Spain = 2970,
    America_Porto_Velho = 2992,
    America_Puerto_Rico = 3012,
    America_Punta_Arenas = 3032,
    America_Rainy_River = 3053,
    America_Rankin_Inlet = 3073,
    America_Recife = 3094,
    America_Regina = 3109,
    America_Resolute = 3124,
    America_Rio_Branco = 3141,
    America_Santarem = 3160,
    America_Santiago = 3177,
    America_Santo_Domingo = 3194,
    America_Sao_Paulo = 3216,
    America_Scoresbysund = 3234,
    America_Sitka = 3255,
    America_St_Barthelemy = 3269,
    America_St_Johns = 3291,
    America_St_Kitts = 3308,
    America_St_Lucia = 3325,
    America_St_Thomas = 3342,
    America_St_Vincent = 3360,
    America_Swift_Current = 3379,
    America_Tegucigalpa = 3401,
    America_Thule = 3421,
    America_Thunder_Bay = 3435,
    America_Tijuana = 3455,
    America_Toronto = 3471,
    America_Tortola = 3487,
    America_Vancouver = 3503,
    America_Whitehorse = 3521,
    America_Winnipeg = 3540,
    America_Yakutat = 3557,
    America_Yellowknife = 3573,
    Antarctica_Macquarie = 3593,
    Arctic_Longyearbyen = 3614,
    Asia_Aden = 3634,
    Asia_Almaty = 3644,
    Asia_Amman = 3656,
    Asia_Anadyr = 3667,
    Asia_Aqtau = 3679,
    Asia_Aqtobe = 3690,
    Asia_Ashgabat = 3702,
    Asia_Atyrau = 3716,
    Asia_Baghdad = 3728,
    Asia_Bahrain = 3741,
    Asia_Baku = 3754,
    Asia_Bangkok = 3764,
    Asia_Barnaul = 3777,
    Asia_Beirut = 3790,
    Asia_Bishkek = 3802,
    Asia_Brunei = 3815,
    Asia_Chita = 3827,
    Asia_Choibalsan = 3838,
    Asia_Colombo = 3854,
    Asia_Damascus = 3867,
    Asia_Dhaka = 3881,
    Asia_Dili = 3892,
    Asia_Dubai = 3902,
    Asia_Dushanbe = 3913,
    Asia_Famagusta = 3927,
    Asia_Gaza = 3942,
    Asia_Hebron = 3952,
    Asia_Ho_Chi_Minh = 3964,
    Asia_Hong_Kong = 3981,
    Asia_Hovd = 3996,
    Asia_Irkutsk = 4006,
    Asia_Jakarta = 4019,
    Asia_Jayapura = 4032,
    Asia_Jerusalem = 4046,
    Asia_Kabul = 4061,
    Asia_Kamchatka = 4072,
    Asia_Karachi = 4087,
    Asia_Kathmandu = 4100,
    Asia_Khandyga = 4115,
    Asia_Kolkata = 4129,
    Asia_Krasnoyarsk = 4142,
    Asia_Kuala_Lumpur = 4159,
    Asia_Kuching = 4177,
    Asia_Kuwait = 4190,
    Asia_Macau = 4202,
    Asia_Magadan = 4213,
    Asia_Makassar = 4226,
    Asia_Manila = 4240,
    Asia_Muscat = 4252,
    Asia_Nicosia = 4264,
    Asia_Novokuznetsk = 4277,
    Asia_Novosibirsk = 4295,
    Asia_Omsk = 4312,
    Asia_Oral = 4322,
    Asia_Phnom_Penh = 4332,
    Asia_Pontianak = 4348,
    Asia_Pyongyang = 4363,
    Asia_Qatar = 4378,
    Asia_Qyzylorda = 4389,
    Asia_Riyadh = 4404,
    Asia_Sakhalin = 4416,
    Asia_Samarkand = 4430,
    Asia_Seoul = 4445,
    Asia_Shanghai = 4456,
    Asia_Singapore = 4470,
    Asia_Srednekolymsk = 4485,
    Asia_Taipei = 4504,
    Asia_Tashkent = 4516,
    Asia_Tbilisi = 4530,
    Asia_Tehran = 4543,
    Asia_Thimphu = 4555,
    Asia_Tokyo = 4568,
    Asia_Tomsk = 4579,
    Asia_Ulaanbaatar = 4590,
    Asia_Urumqi = 4607,
    Asia_Ust_Nera = 4619,
    Asia_Vientiane = 4633,
    Asia_Vladivostok = 4648,
    Asia_Yakutsk = 4665,
    Asia_Yangon = 4678,
    Asia_Yekaterinburg = 4690,
    Asia_Yerevan = 4709,
    Atlantic_Azores = 4722,
    Atlantic_Bermuda = 4738,
    Atlantic_Canary = 4755,
    Atlantic_Cape_Verde = 4771,
    Atlantic_Faroe = 4791,
    Atlantic_Madeira = 4806,
    Atlantic_Reykjavik = 4823,
    Atlantic_South_Georgia = 4842,
    Atlantic_St_Helena = 4865,
    Atlantic_Stanley = 4884,
    Australia_Adelaide = 4901,
    Australia_Brisbane = 4920,
    Australia_Broken_Hill = 4939,
    Australia_Currie = 4961,
    Australia_Darwin = 4978,
    Australia_Eucla = 4995,
    Australia_Hobart = 5011,
    Australia_Lindeman = 5028,
    Australia_Lord_Howe = 5047,
    Australia_Melbourne = 5067,
    Australia_Perth = 5087,
    Australia_Sydney = 5103,
    Europe_Amsterdam = 5120,
    Europe_Andorra = 5137,
    Europe_Astrakhan = 5152,
    Europe_Athens = 5169,
    Europe_Belgrade = 5183,
    Europe_Berlin = 5199,
    Europe_Bratislava = 5213,
    Europe_Brussels = 5231,
    Europe_Bucharest = 5247,
    Europe_Budapest = 5264,
    Europe_Busingen = 5280,
    Europe_Chisinau = 5296,
    Europe_Copenhagen = 5312,
    Europe_Dublin = 5330,
    Europe_Gibraltar = 5344,
    Europe_Guernsey = 5361,
    Europe_Helsinki = 5377,
    Europe_Isle_of_Man = 5393,
    Europe_Istanbul = 5412,
    Europe_Jersey = 5428,
    Europe_Kaliningrad = 5442,
    Europe_Kiev = 5461,
    Europe_Kirov = 5473,
    Europe_Lisbon = 5486,
    Europe_Ljubljana = 5500,
    Europe_London = 5517,
    Europe_Luxembourg = 5531,
    Europe_Madrid = 5549,
    Europe_Malta = 5563,
    Europe_Mariehamn = 5576,
    Europe_Minsk = 5593,
    Europe_Monaco = 5606,
    Europe_Moscow = 5620,
    Europe_Oslo = 5634,
    Europe_Paris = 5646,
    Europe_Podgorica = 5659,
    Europe_Prague = 5676,
    Europe_Riga = 5690,
    Europe_Rome = 5702,
    Europe_Samara = 5714,
    Europe_San_Marino = 5728,
    Europe_Sarajevo = 5746,
    Europe_Saratov = 5762,
    Europe_Simferopol = 5777,
    Europe_Skopje = 5795,
    Europe_Sofia = 5809,
    Europe_Stockholm = 5822,
    Europe_Tallinn = 5839,
    Europe_Tirane = 5854,
    Europe_Ulyanovsk = 5868,
    Europe_Uzhgorod = 5885,
    Europe_Vaduz = 5901,
    Europe_Vatican = 5914,
    Europe_Vienna = 5929,
    Europe_Vilnius = 5943,
    Europe_Volgograd = 5958,
    Europe_Warsaw = 5975,
    Europe_Zagreb = 5989,
    Europe_Zaporozhye = 6003,
    Europe_Zurich = 6021,
    Indian_Antananarivo = 6035,
    Indian_Chagos = 6055,
    Indian_Christmas = 6069,
    Indian_Cocos = 6086,
    Indian_Comoro = 6099,
    Indian_Kerguelen = 6113,
    Indian_Mahe = 6130,
    Indian_Maldives = 6142,
    Indian_Mauritius = 6158,
    Indian_Mayotte = 6175,
    Indian_Reunion = 6190,
    Pacific_Apia = 6205,
    Pacific_Auckland = 6218,
    Pacific_Bougainville = 6235,
    Pacific_Chatham = 6256,
    Pacific_Chuuk = 6272,
    Pacific_Easter = 6286,
    Pacific_Efate = 6301,
    Pacific_Enderbury = 6315,
    Pacific_Fakaofo = 6333,
    Pacific_Fiji = 6349,
    Pacific_Funafuti = 6362,
    Pacific_Galapagos = 6379,
    Pacific_Gambier = 6397,
    Pacific_Guadalcanal = 6413,
    Pacific_Guam = 6433,
    Pacific_Honolulu = 6446,
    Pacific_Kiritimati = 6463,
    Pacific_Kosrae = 6482,
    Pacific_Kwajalein = 6497,
    Pacific_Majuro = 6515,
    Pacific_Marquesas = 6530,
    Pacific_Midway = 6548,
    Pacific_Nauru = 6563,
    Pacific_Niue = 6577,
    Pacific_Norfolk = 6590,
    Pacific_Noumea = 6606,
    Pacific_Pago_Pago = 6621,
    Pacific_Palau = 6639,
    Pacific_Pitcairn = 6653,
    Pacific_Pohnpei = 6670,
    Pacific_Port_Moresby = 6686,
    Pacific_Rarotonga = 6707,
    Pacific_Saipan = 6725,
    Pacific_Tahiti = 6740,
    Pacific_Tarawa = 6755,
    Pacific_Tongatapu = 6770,
    Pacific_Wake = 6788,
    Pacific_Wallis = 6801,
};

}
}

#endif
